#
# spec file for package cura-lulzbot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cura-lulzbot
Version:        3.6.5
Release:        lp151.1.1
Summary:        3D printer control software
License:        AGPL-3.0-only
Group:          Hardware/Printing
Url:            https://code.alephobjects.com/source/cura-lulzbot.git
Source0:        %name-%{version}.tar.xz
# PATCH-FIX-OPENSUSE fix-build.patch -- adapt SUSE python install path
Patch1:         fix-build.patch
# PATCH-FIX-OPENSUSE CuraEngine-lulzbot.patch -- use lulzbot variant of CuraEngine by default
Patch2:         CuraEngine-lulzbot.patch
BuildArch:      noarch
Provides:       cura2-lulzbot
Obsoletes:      cura2-lulzbot < 3
Conflicts:      cura
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  icoutils
BuildRequires:  gettext-tools
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  uranium-lulzbot
Requires:       cura-engine-lulzbot = %version
Requires:       uranium-lulzbot = %version
# dependency scripts do not find qtquickcontrols automatically
Requires:       libqt5-qtquickcontrols2
Requires:       python3-numpy
Requires:       python3-opengl
Requires:       python3-power
Requires:       python3-pyserial
Requires:       python3-qt5
Requires:       python3-scipy
Requires:       python3-sip
Requires:       python3-zeroconf

# There is a hardcoded version to the firmware in the code :/ 
Requires:       uranium-firmware-lulzbot = %( tar xf %{S:0} --wildcards \*/USBPrinterOutputDeviceManager.py --to-command='sed -n -e "s,.*Marlin_Mini_SingleExtruder_\([^_]*_[^_]*\).hex.*,\1,p"' )

%description
Cura is a software solution for 3D printing.
While it is developed to be used with the Ultimaker 3D printer, it can be used
with other RepRap based designs.

Cura helps in setting up an Ultimaker, shows 3D models, allows for scaling /
positioning, can slice the model to G-Code, has editable configuration
settings, and send this G-Code to the 3D printer for printing.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
sed -i -e 's,@CURA_VERSION@,%version,' cura/CuraVersion.py.in
sed -i -e 's,@CURA_BUILDTYPE@,release,' cura/CuraVersion.py.in
sed -i -e 's,CuraDebugMode = .*,CuraDebugMode = False,' cura/CuraVersion.py.in
%cmake -DURANIUM_DIR=/usr/lib/uranium -DURANIUM_SCRIPTS_DIR=/usr/share/uranium/resources/scripts -DCURA_DEBUGMODE=OFF
make %{?_smp_mflags}

%install
cd build
%make_install
install -m 0644 ../version.json %buildroot/usr/share/cura/
%suse_update_desktop_file cura-lulzbot Graphics 3DGraphics
sed -i -e 's,^Exec=.*,Exec=cura-lulzbot %F,' \
       -e 's,^#!/usr/bin/env.*,#!/usr/bin/python3,' \
    %{buildroot}%{_datadir}/applications/cura-lulzbot.desktop
%fdupes %buildroot

%files
%defattr (-,root,root,-)
%license LICENSE
%doc README.md
%{python3_sitelib}/cura
%{_datadir}/cura
%{_datadir}/applications/cura-lulzbot.desktop
%{_datadir}/mime/packages/cura.xml
%{_datadir}/appdata/cura.appdata.xml
%{_bindir}/cura-lulzbot
/usr/lib/cura

%changelog
* Fri Apr  5 2019 Adrian Schröter <adrian@suse.de>
- update to 3.6.5
    T1868: [Quiver] Changed firmware printer and toolheads definitions to correspond to ones in Marlin.
    T1868, T5980: Added FW files definitions for Quiver.
    T5686: [BUG] Fix for exception observed in T6071.
    T1626: [BUG] The search function introduced was causing "cannot use a bytes pattern on a string-like object" exception.
    T6100 updating quiver build volumes
    T6088 removing support extruder from quiver profiles
    T5688: Fixed wrong comparison statement which were causing "PROBE FAIL CLEAN NOZZLE" condition.
    T6009: [Quiver] Updating start and end gcode.
    T5823: [TAZ6] Updating MOARStruder start g-code.
    T5832, T5831, T5830, T5829, T5072: [Quiver] Updating profile settings for Evergreen Bagworm.
    T6004: [Quiver] Disabling backlash fading for Evergreen Bagworm.
    T5923: [Quiver] Adding missing profiles for xstrand and colorFabb PA-CF.
    T5832, T5831, T5830, T5829: [Quiver] Updating quiver profiles for Evergreen Bagworm.
    T5823: [Quiver] Updating Evergreen Bagworm profiles.
    T1868: [Quiver] Updating customer facing tool head name.
    T1868: [Quiver] Tool head order and printer order adjusted.
    T1868: [Quiver] Fixing bed STL location.
    T1868: [Quiver] Updating bed STL file, customer facing names, printer locations.
    T5842: added rambo driver installation
    T4367: QML error fixed.
    T1273: Another fix for correct handling of control undefined case.
    Added missing setting_control_radius options for all themes.
    T3377: Top border of extrusion amount field changed.
    Workaround for G29 crashing Marlin (T5686)
    updating dark theme printing text T5783
    Explicitly call out T0 in M104
    Restored message that was mistakenly removed.
    Enhancements for USB printing (T5697, T5685, T5688)
  - Implemented more "//action:" commands.
  - Cool down T1 on print abort.
  - Shut off print timer on print abort.
  - Pause/resume print timer on print pause/resume.
  - Reset filament sensor on print resume.
    T3377: Values in Manual Control section  now saves after switch to Prepeare stage
    T5549: Extruder disallowed areas function added.
* Wed Feb 20 2019 Adrian Schröter <adrian@suse.de>
- update to 3.6.4
  * T1250: Added list of serial port USB VIDs that will be autodetected by USB printer plugin.
  * T1250: For port autodetection, we should use pyserial tools instead of programmer.
  * T1250: Commenting out some too verbose log messages.
  * Merge branch 'master' into T1250
  * T1250: The minimum set of code that flashes Archim board is now working.
  * Verifying flash and progress hooks are not implemented yet.
  * T1250: Added WordCopy applet and added mor functions to Samba and EEFC Flash.
  * T1250: Added classes for SAM-BA and EEFC flash.
  * T1250: Added some chips to the chip DB.
  * T5129 updating Q start gcode
  * T5522 updating tool tip for accel and jerk control for LB printers only
  * T5551 updating single tool head start gcode, quiver
  * Fix for 9a2a39ab9afc
  * Merge branch 'master' into T1250
  * Merge branch 'T5198'
  * T5189 Polycast profile addition, move to intermediate
  * T5467 fixing job specs background
  * T5465 updating file name to dark green
  * T5465 adding lulzbot dark theme
  * T5198 T5419 fixed support infill layer thickness
  * Merge branch 'T5184'
  * T5198 removing support infill thickness
  * T5072 adding no material and profiles to v3 and evergeen bagworm
  * Changed Marlin FW to v1.1.9.34 for all LulzBot printers.
  * T1868 adding Q - HS machine, materials, profiles, gcode, extruder
  * T1868 adding Q - HS+ machine, materials, profiles, gcode, extruder
  * T1868 adding Quiver SL machine, profiles, extruders, gcodes, materials
  * T1868 adding Q - SE machine, materials, extruder, profiles
  * T4924: Extruder 2 progress bar color changed.
  * T4945 removing g21 from start gcode
  * T5184 Support Eraser plugin
  * T5198: fixed resolve function
  * T5043: Custom support plugin
  * T5034: fixed transfet of model extruders on multiplication
  * T1868 updating start and end gcode for Q
  * T5130 updating q end gcode
  * T5121 more polycast profiles
  * T5121 adding polycast profiles
  * adding polycast T5121
  * T5061 adding PVA to q
  * adding polydissolve to q T5061
  * T1250: Added more functionality to bossapy. It enters bootloader and reads ChipID now upon trying to flash BIN file. It's still not functioning properly.
  * T1250: Added initial (dummy) version of bossa programmer.
* Wed Jan  9 2019 Adrian Schröter <adrian@suse.de>
- update to version 3.6.1
  https://code.alephobjects.com/w/cura-lulzbot/
* Tue Nov 20 2018 Adrian Schröter <adrian@suse.de>
- update to version 3.2.32
  * profile updates
* Mon Oct 22 2018 Adrian Schröter <adrian@suse.de>
- update to 3.2.29
  * Improved error handling in MarlinSerialProtocol.
  * Tested to operate more reliabily with Marlin 1.1.9 with no lock-ups at
  * high error rates.
  * fixing bridge cooling setting
  * More spacing for add machine dialog.
  * Dingy PETg profile updates
  * adding machine, extruders, materials, profiles, start gcode
  * updating alloy 910 temperatures
  * updating banded and dingy customer facing names
* Tue Sep 25 2018 Adrian Schröter <adrian@suse.de>
- update to 3.2.28
  * Marlin FW dep to 1.1.9.17_82d1e4ffa
  * profile updates
* Mon Aug  6 2018 adrian@suse.de
- update to version 3.2.24
  * Changed Marlin FW to v1.1.8.66
  * double loading of models fixed
  * profile updates
* Fri Jul 13 2018 adrian@suse.de
- update to version 3.2.23
  * profile updates
* Thu Jul 12 2018 adrian@suse.de
- fixed missing sidebar
  * added dependency to libqt5-qtquickcontrols2
* Tue Jul  3 2018 adrian@suse.de
- update to version 3.2.22
  * new blacklash option
* Wed May 30 2018 adrian@suse.de
- update to version 3.2.21
  * Changed Marlin FW to v1.1.8.59
  * mostly improvements for Mini 2
* Mon May 14 2018 adrian@suse.de
- update to version 3.2.20
  * Changed Marlin FW to v1.1.8.51
  * minor bugfixes
* Wed May  2 2018 adrian@suse.de
- update to version 3.2.19
  * Changed Marlin FW to v1.1.8.42
  * Mini 2 support (former Hibiscus)
  * various printer fixes
* Thu Apr 19 2018 adrian@suse.de
- update to version 3.2.18
  * Changed Marlin FW to vv1.1.8.29
  * various printer fixes
* Mon Mar 26 2018 adrian@suse.de
- update to version 3.2.16
  * Changed Marlin FW to v1.1.8.21
  * fixed profiles filter in preferences page
  * fix bed pre-heat button
  * updating Polylite Standard print temp
  * Further UI and material updates
- compile in cura version
* Thu Mar  8 2018 adrian@suse.de
- update to version 3.2.9
  * Updates for various printers
* Wed Jan 31 2018 jengelh@inai.de
- Say what the package does, not what it aims to do in future.
* Wed Jan 31 2018 adrian@suse.de
- update to version 3.2.1
  * entire rewrite
  * supports network and headless mode
- Patches:
  dynamic-linking.patch was never applied on the package, but
    factory check scripts got confused due
    to rename
  fix-build.patch: adapt SUSE python installation pathes
  CuraEngine-lulzbot.patch: Find the LulzBot CuraEngine by default
* Wed Jan  3 2018 adrian@suse.de
- fix license tag
* Fri Sep  8 2017 adrian@suse.de
- fix startup crash due to missing libglut3
* Tue Jul 25 2017 jengelh@inai.de
- Fix grammatical errors.
* Mon Jul 24 2017 adrian@suse.de
- update to version 21.06
  * use original upstream tar ball
  * clone curaengine via source service since it is not included anymore
* Mon Jun 26 2017 adrian@suse.de
- avoid conflicts with cura 2
- link CuraEngine dynamic
- open documentation using xdg-open instead of hardcoded Firefox
* Wed Jun 21 2017 adrian@suse.de
- initial package based on upstream package for Fedora
